/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

/**
 * Font icon plugin for htmlArea RTE
 */
define('TYPO3/CMS/Rtehtmlarea/Plugins/InsertIcon',
    ['TYPO3/CMS/Rtehtmlarea/HTMLArea/Plugin/Plugin',
        'TYPO3/CMS/Rtehtmlarea/HTMLArea/Util/Util'],
    function (Plugin, Util) {

        var InsertIcon = function (editor, pluginName) {
            this.constructor.super.call(this, editor, pluginName);
        };
        Util.inherit(InsertIcon, Plugin);
        Util.apply(InsertIcon.prototype, {

            configurePlugin: function (editor) {
                this.pageTSConfiguration = this.editorConfiguration.buttons.fonticon;
                /**
                 * Available iocns
                 */
                this.icons = [
                    WebApplication = [
                        { class: 'fa fa-adjust', title: 'adjust'},
                        { class: 'fa fa-anchor', title: 'anchor'},
                        { class: 'fa fa-archive', title: 'archive'},
                        { class: 'fa fa-area-chart', title: 'area-chart'},
                        { class: 'fa fa-arrows', title: 'arrows'},
                        { class: 'fa fa-arrows-h', title: 'arrows-h'},
                        { class: 'fa fa-arrows-v', title: 'arrows-v'},
                        { class: 'fa fa-asterisk', title: 'asterisk'},
                        { class: 'fa fa-at', title: 'at'},
                        { class: 'fa fa-balance-scale', title: 'balance-scale'},
                        { class: 'fa fa-ban', title: 'ban'},
                        { class: 'fa fa-bar-chart', title: 'bar-chart'},
                        { class: 'fa fa-barcode', title: 'barcode'},
                        { class: 'fa fa-bars', title: 'bars'},
                        { class: 'fa fa-battery-empty', title: 'battery-empty'},
                        { class: 'fa fa-battery-full', title: 'battery-full'},
                        { class: 'fa fa-battery-half', title: 'battery-half'},
                        { class: 'fa fa-battery-quarter', title: 'battery-quarter'},
                        { class: 'fa fa-battery-three-quarters', title: 'battery-three-quarters'},
                        { class: 'fa fa-bed', title: 'bed'},
                        { class: 'fa fa-beer', title: 'beer'},
                        { class: 'fa fa-bell', title: 'bell'},
                        { class: 'fa fa-bell-o', title: 'bell-o'},
                        { class: 'fa fa-bell-slash', title: 'bell-slash'},
                        { class: 'fa fa-bell-slash-o', title: 'bell-slash-o'},
                        { class: 'fa fa-bicycle', title: 'bicycle'},
                        { class: 'fa fa-binoculars', title: 'binoculars'},
                        { class: 'fa fa-birthday-cake', title: 'birthday-cake'},
                        { class: 'fa fa-bolt', title: 'bolt'},
                        { class: 'fa fa-bomb', title: 'bomb'},
                        { class: 'fa fa-book', title: 'book'},
                        { class: 'fa fa-bookmark', title: 'bookmark'},
                        { class: 'fa fa-bookmark-o', title: 'bookmark-o'},
                        { class: 'fa fa-briefcase', title: 'briefcase'},
                        { class: 'fa fa-bug', title: 'bug'},
                        { class: 'fa fa-building', title: 'building'},
                        { class: 'fa fa-building-o', title: 'building-o'},
                        { class: 'fa fa-bullhorn', title: 'bullhorn'},
                        { class: 'fa fa-bullseye', title: 'bullseye'},
                        { class: 'fa fa-bus', title: 'bus'},
                        { class: 'fa fa-calculator', title: 'calculator'},
                        { class: 'fa fa-calendar', title: 'calendar'},
                        { class: 'fa fa-calendar-check-o', title: 'calendar-check-o'},
                        { class: 'fa fa-calendar-minus-o', title: 'calendar-minus-o'},
                        { class: 'fa fa-calendar-o', title: 'calendar-o'},
                        { class: 'fa fa-calendar-plus-o', title: 'calendar-plus-o'},
                        { class: 'fa fa-calendar-times-o', title: 'calendar-times-o'},
                        { class: 'fa fa-camera', title: 'camera'},
                        { class: 'fa fa-camera-retro', title: 'camera-retro'},
                        { class: 'fa fa-car', title: 'car'},
                        { class: 'fa fa-caret-square-o-down', title: 'caret-square-o-down'},
                        { class: 'fa fa-caret-square-o-left', title: 'caret-square-o-left'},
                        { class: 'fa fa-caret-square-o-right', title: 'caret-square-o-right'},
                        { class: 'fa fa-caret-square-o-up', title: 'caret-square-o-up'},
                        { class: 'fa fa-cart-arrow-down', title: 'cart-arrow-down'},
                        { class: 'fa fa-cart-plus', title: 'cart-plus'},
                        { class: 'fa fa-cc', title: 'cc'},
                        { class: 'fa fa-certificate', title: 'certificate'},
                        { class: 'fa fa-check', title: 'check'},
                        { class: 'fa fa-check-circle', title: 'check-circle'},
                        { class: 'fa fa-check-circle-o', title: 'check-circle-o'},
                        { class: 'fa fa-check-square', title: 'check-square'},
                        { class: 'fa fa-check-square-o', title: 'check-square-o'},
                        { class: 'fa fa-child', title: 'child'},
                        { class: 'fa fa-circle', title: 'circle'},
                        { class: 'fa fa-circle-o', title: 'circle-o'},
                        { class: 'fa fa-circle-o-notch', title: 'circle-o-notch'},
                        { class: 'fa fa-circle-thin', title: 'circle-thin'},
                        { class: 'fa fa-clock-o', title: 'clock-o'},
                        { class: 'fa fa-clone', title: 'clone'},
                        { class: 'fa fa-cloud', title: 'cloud'},
                        { class: 'fa fa-cloud-download', title: 'cloud-download'},
                        { class: 'fa fa-cloud-upload', title: 'cloud-upload'},
                        { class: 'fa fa-code', title: 'code'},
                        { class: 'fa fa-code-fork', title: 'code-fork'},
                        { class: 'fa fa-coffee', title: 'coffee'},
                        { class: 'fa fa-cog', title: 'cog'},
                        { class: 'fa fa-cogs', title: 'cogs'},
                        { class: 'fa fa-comment', title: 'comment'},
                        { class: 'fa fa-comment-o', title: 'comment-o'},
                        { class: 'fa fa-commenting', title: 'commenting'},
                        { class: 'fa fa-commenting-o', title: 'commenting-o'},
                        { class: 'fa fa-comments', title: 'comments'},
                        { class: 'fa fa-comments-o', title: 'comments-o'},
                        { class: 'fa fa-compass', title: 'compass'},
                        { class: 'fa fa-copyright', title: 'copyright'},
                        { class: 'fa fa-creative-commons', title: 'creative-commons'},
                        { class: 'fa fa-credit-card', title: 'credit-card'},
                        { class: 'fa fa-crop', title: 'crop'},
                        { class: 'fa fa-crosshairs', title: 'crosshairs'},
                        { class: 'fa fa-cube', title: 'cube'},
                        { class: 'fa fa-cubes', title: 'cubes'},
                        { class: 'fa fa-cutlery', title: 'cutlery'},
                        { class: 'fa fa-database', title: 'database'},
                        { class: 'fa fa-desktop', title: 'desktop'},
                        { class: 'fa fa-diamond', title: 'diamond'},
                        { class: 'fa fa-dot-circle-o', title: 'dot-circle-o'},
                        { class: 'fa fa-download', title: 'download'},
                        { class: 'fa fa-ellipsis-h', title: 'ellipsis-h'},
                        { class: 'fa fa-ellipsis-v', title: 'ellipsis-v'},
                        { class: 'fa fa-envelope', title: 'envelope'},
                        { class: 'fa fa-envelope-o', title: 'envelope-o'},
                        { class: 'fa fa-envelope-square', title: 'envelope-square'},
                        { class: 'fa fa-eraser', title: 'eraser'},
                        { class: 'fa fa-exchange', title: 'exchange'},
                        { class: 'fa fa-exclamation', title: 'exclamation'},
                        { class: 'fa fa-exclamation-circle', title: 'exclamation-circle'},
                        { class: 'fa fa-exclamation-triangle', title: 'exclamation-triangle'},
                        { class: 'fa fa-external-link', title: 'external-link'},
                        { class: 'fa fa-external-link-square', title: 'external-link-square'},
                        { class: 'fa fa-eye', title: 'eye'},
                        { class: 'fa fa-eye-slash', title: 'eye-slash'},
                        { class: 'fa fa-eyedropper', title: 'eyedropper'},
                        { class: 'fa fa-fax', title: 'fax'},
                        { class: 'fa fa-female', title: 'female'},
                        { class: 'fa fa-fighter-jet', title: 'fighter-jet'},
                        { class: 'fa fa-file-archive-o', title: 'file-archive-o'},
                        { class: 'fa fa-file-audio-o', title: 'file-audio-o'},
                        { class: 'fa fa-file-code-o', title: 'file-code-o'},
                        { class: 'fa fa-file-excel-o', title: 'file-excel-o'},
                        { class: 'fa fa-file-image-o', title: 'file-image-o'},
                        { class: 'fa fa-file-pdf-o', title: 'file-pdf-o'},
                        { class: 'fa fa-file-powerpoint-o', title: 'file-powerpoint-o'},
                        { class: 'fa fa-file-video-o', title: 'file-video-o'},
                        { class: 'fa fa-file-word-o', title: 'file-word-o'},
                        { class: 'fa fa-film', title: 'film'},
                        { class: 'fa fa-filter', title: 'filter'},
                        { class: 'fa fa-fire', title: 'fire'},
                        { class: 'fa fa-fire-extinguisher', title: 'fire-extinguisher'},
                        { class: 'fa fa-flag', title: 'flag'},
                        { class: 'fa fa-flag-checkered', title: 'flag-checkered'},
                        { class: 'fa fa-flag-o', title: 'flag-o'},
                        { class: 'fa fa-flask', title: 'flask'},
                        { class: 'fa fa-folder', title: 'folder'},
                        { class: 'fa fa-folder-o', title: 'folder-o'},
                        { class: 'fa fa-folder-open', title: 'folder-open'},
                        { class: 'fa fa-folder-open-o', title: 'folder-open-o'},
                        { class: 'fa fa-frown-o', title: 'frown-o'},
                        { class: 'fa fa-futbol-o', title: 'futbol-o'},
                        { class: 'fa fa-gamepad', title: 'gamepad'},
                        { class: 'fa fa-gavel', title: 'gavel'},
                        { class: 'fa fa-gift', title: 'gift'},
                        { class: 'fa fa-glass', title: 'glass'},
                        { class: 'fa fa-globe', title: 'globe'},
                        { class: 'fa fa-graduation-cap', title: 'graduation-cap'},
                        { class: 'fa fa-hand-lizard-o', title: 'hand-lizard-o'},
                        { class: 'fa fa-hand-paper-o', title: 'hand-paper-o'},
                        { class: 'fa fa-hand-peace-o', title: 'hand-peace-o'},
                        { class: 'fa fa-hand-pointer-o', title: 'hand-pointer-o'},
                        { class: 'fa fa-hand-rock-o', title: 'hand-rock-o'},
                        { class: 'fa fa-hand-scissors-o', title: 'hand-scissors-o'},
                        { class: 'fa fa-hand-spock-o', title: 'hand-spock-o'},
                        { class: 'fa fa-hdd-o', title: 'hdd-o'},
                        { class: 'fa fa-headphones', title: 'headphones'},
                        { class: 'fa fa-heart', title: 'heart'},
                        { class: 'fa fa-heart-o', title: 'heart-o'},
                        { class: 'fa fa-heartbeat', title: 'heartbeat'},
                        { class: 'fa fa-history', title: 'history'},
                        { class: 'fa fa-home', title: 'home'},
                        { class: 'fa fa-hourglass', title: 'hourglass'},
                        { class: 'fa fa-hourglass-end', title: 'hourglass-end'},
                        { class: 'fa fa-hourglass-half', title: 'hourglass-half'},
                        { class: 'fa fa-hourglass-o', title: 'hourglass-o'},
                        { class: 'fa fa-hourglass-start', title: 'hourglass-start'},
                        { class: 'fa fa-i-cursor', title: 'i-cursor'},
                        { class: 'fa fa-inbox', title: 'inbox'},
                        { class: 'fa fa-industry', title: 'industry'},
                        { class: 'fa fa-info', title: 'info'},
                        { class: 'fa fa-info-circle', title: 'info-circle'},
                        { class: 'fa fa-key', title: 'key'},
                        { class: 'fa fa-keyboard-o', title: 'keyboard-o'},
                        { class: 'fa fa-language', title: 'language'},
                        { class: 'fa fa-laptop', title: 'laptop'},
                        { class: 'fa fa-leaf', title: 'leaf'},
                        { class: 'fa fa-lemon-o', title: 'lemon-o'},
                        { class: 'fa fa-level-down', title: 'level-down'},
                        { class: 'fa fa-level-up', title: 'level-up'},
                        { class: 'fa fa-life-ring', title: 'life-ring'},
                        { class: 'fa fa-lightbulb-o', title: 'lightbulb-o'},
                        { class: 'fa fa-line-chart', title: 'line-chart'},
                        { class: 'fa fa-location-arrow', title: 'location-arrow'},
                        { class: 'fa fa-lock', title: 'lock'},
                        { class: 'fa fa-magic', title: 'magic'},
                        { class: 'fa fa-magnet', title: 'magnet'},
                        { class: 'fa fa-male', title: 'male'},
                        { class: 'fa fa-map', title: 'map'},
                        { class: 'fa fa-map-marker', title: 'map-marker'},
                        { class: 'fa fa-map-o', title: 'map-o'},
                        { class: 'fa fa-map-pin', title: 'map-pin'},
                        { class: 'fa fa-map-signs', title: 'map-signs'},
                        { class: 'fa fa-meh-o', title: 'meh-o'},
                        { class: 'fa fa-microphone', title: 'microphone'},
                        { class: 'fa fa-microphone-slash', title: 'microphone-slash'},
                        { class: 'fa fa-minus', title: 'minus'},
                        { class: 'fa fa-minus-circle', title: 'minus-circle'},
                        { class: 'fa fa-minus-square', title: 'minus-square'},
                        { class: 'fa fa-minus-square-o', title: 'minus-square-o'},
                        { class: 'fa fa-mobile', title: 'mobile'},
                        { class: 'fa fa-money', title: 'money'},
                        { class: 'fa fa-moon-o', title: 'moon-o'},
                        { class: 'fa fa-motorcycle', title: 'motorcycle'},
                        { class: 'fa fa-mouse-pointer', title: 'mouse-pointer'},
                        { class: 'fa fa-music', title: 'music'},
                        { class: 'fa fa-newspaper-o', title: 'newspaper-o'},
                        { class: 'fa fa-object-group', title: 'object-group'},
                        { class: 'fa fa-object-ungroup', title: 'object-ungroup'},
                        { class: 'fa fa-paint-brush', title: 'paint-brush'},
                        { class: 'fa fa-paper-plane', title: 'paper-plane'},
                        { class: 'fa fa-paper-plane-o', title: 'paper-plane-o'},
                        { class: 'fa fa-paw', title: 'paw'},
                        { class: 'fa fa-pencil', title: 'pencil'},
                        { class: 'fa fa-pencil-square', title: 'pencil-square'},
                        { class: 'fa fa-pencil-square-o', title: 'pencil-square-o'},
                        { class: 'fa fa-phone', title: 'phone'},
                        { class: 'fa fa-phone-square', title: 'phone-square'},
                        { class: 'fa fa-picture-o', title: 'picture-o'},
                        { class: 'fa fa-pie-chart', title: 'pie-chart'},
                        { class: 'fa fa-plane', title: 'plane'},
                        { class: 'fa fa-plug', title: 'plug'},
                        { class: 'fa fa-plus', title: 'plus'},
                        { class: 'fa fa-plus-circle', title: 'plus-circle'},
                        { class: 'fa fa-plus-square', title: 'plus-square'},
                        { class: 'fa fa-plus-square-o', title: 'plus-square-o'},
                        { class: 'fa fa-power-off', title: 'power-off'},
                        { class: 'fa fa-print', title: 'print'},
                        { class: 'fa fa-puzzle-piece', title: 'puzzle-piece'},
                        { class: 'fa fa-qrcode', title: 'qrcode'},
                        { class: 'fa fa-question', title: 'question'},
                        { class: 'fa fa-question-circle', title: 'question-circle'},
                        { class: 'fa fa-quote-left', title: 'quote-left'},
                        { class: 'fa fa-quote-right', title: 'quote-right'},
                        { class: 'fa fa-random', title: 'random'},
                        { class: 'fa fa-recycle', title: 'recycle'},
                        { class: 'fa fa-refresh', title: 'refresh'},
                        { class: 'fa fa-registered', title: 'registered'},
                        { class: 'fa fa-reply', title: 'reply'},
                        { class: 'fa fa-reply-all', title: 'reply-all'},
                        { class: 'fa fa-retweet', title: 'retweet'},
                        { class: 'fa fa-road', title: 'road'},
                        { class: 'fa fa-rocket', title: 'rocket'},
                        { class: 'fa fa-rss', title: 'rss'},
                        { class: 'fa fa-rss-square', title: 'rss-square'},
                        { class: 'fa fa-search', title: 'search'},
                        { class: 'fa fa-search-minus', title: 'search-minus'},
                        { class: 'fa fa-search-plus', title: 'search-plus'},
                        { class: 'fa fa-server', title: 'server'},
                        { class: 'fa fa-share', title: 'share'},
                        { class: 'fa fa-share-alt', title: 'share-alt'},
                        { class: 'fa fa-share-alt-square', title: 'share-alt-square'},
                        { class: 'fa fa-share-square', title: 'share-square'},
                        { class: 'fa fa-share-square-o', title: 'share-square-o'},
                        { class: 'fa fa-shield', title: 'shield'},
                        { class: 'fa fa-ship', title: 'ship'},
                        { class: 'fa fa-shopping-cart', title: 'shopping-cart'},
                        { class: 'fa fa-sign-in', title: 'sign-in'},
                        { class: 'fa fa-sign-out', title: 'sign-out'},
                        { class: 'fa fa-signal', title: 'signal'},
                        { class: 'fa fa-sitemap', title: 'sitemap'},
                        { class: 'fa fa-sliders', title: 'sliders'},
                        { class: 'fa fa-smile-o', title: 'smile-o'},
                        { class: 'fa fa-sort', title: 'sort'},
                        { class: 'fa fa-sort-alpha-asc', title: 'sort-alpha-asc'},
                        { class: 'fa fa-sort-alpha-desc', title: 'sort-alpha-desc'},
                        { class: 'fa fa-sort-amount-asc', title: 'sort-amount-asc'},
                        { class: 'fa fa-sort-amount-desc', title: 'sort-amount-desc'},
                        { class: 'fa fa-sort-asc', title: 'sort-asc'},
                        { class: 'fa fa-sort-desc', title: 'sort-desc'},
                        { class: 'fa fa-sort-numeric-asc', title: 'sort-numeric-asc'},
                        { class: 'fa fa-sort-numeric-desc', title: 'sort-numeric-desc'},
                        { class: 'fa fa-space-shuttle', title: 'space-shuttle'},
                        { class: 'fa fa-spinner', title: 'spinner'},
                        { class: 'fa fa-spoon', title: 'spoon'},
                        { class: 'fa fa-square', title: 'square'},
                        { class: 'fa fa-square-o', title: 'square-o'},
                        { class: 'fa fa-star', title: 'star'},
                        { class: 'fa fa-star-half', title: 'star-half'},
                        { class: 'fa fa-star-half-o', title: 'star-half-o'},
                        { class: 'fa fa-star-o', title: 'star-o'},
                        { class: 'fa fa-sticky-note', title: 'sticky-note'},
                        { class: 'fa fa-sticky-note-o', title: 'sticky-note-o'},
                        { class: 'fa fa-street-view', title: 'street-view'},
                        { class: 'fa fa-suitcase', title: 'suitcase'},
                        { class: 'fa fa-sun-o', title: 'sun-o'},
                        { class: 'fa fa-tablet', title: 'tablet'},
                        { class: 'fa fa-tachometer', title: 'tachometer'},
                        { class: 'fa fa-tag', title: 'tag'},
                        { class: 'fa fa-tags', title: 'tags'},
                        { class: 'fa fa-tasks', title: 'tasks'},
                        { class: 'fa fa-taxi', title: 'taxi'},
                        { class: 'fa fa-television', title: 'television'},
                        { class: 'fa fa-terminal', title: 'terminal'},
                        { class: 'fa fa-thumb-tack', title: 'thumb-tack'},
                        { class: 'fa fa-thumbs-down', title: 'thumbs-down'},
                        { class: 'fa fa-thumbs-o-down', title: 'thumbs-o-down'},
                        { class: 'fa fa-thumbs-o-up', title: 'thumbs-o-up'},
                        { class: 'fa fa-thumbs-up', title: 'thumbs-up'},
                        { class: 'fa fa-ticket', title: 'ticket'},
                        { class: 'fa fa-times', title: 'times'},
                        { class: 'fa fa-times-circle', title: 'times-circle'},
                        { class: 'fa fa-times-circle-o', title: 'times-circle-o'},
                        { class: 'fa fa-tint', title: 'tint'},
                        { class: 'fa fa-toggle-off', title: 'toggle-off'},
                        { class: 'fa fa-toggle-on', title: 'toggle-on'},
                        { class: 'fa fa-trademark', title: 'trademark'},
                        { class: 'fa fa-trash', title: 'trash'},
                        { class: 'fa fa-trash-o', title: 'trash-o'},
                        { class: 'fa fa-tree', title: 'tree'},
                        { class: 'fa fa-trophy', title: 'trophy'},
                        { class: 'fa fa-truck', title: 'truck'},
                        { class: 'fa fa-tty', title: 'tty'},
                        { class: 'fa fa-umbrella', title: 'umbrella'},
                        { class: 'fa fa-university', title: 'university'},
                        { class: 'fa fa-unlock', title: 'unlock'},
                        { class: 'fa fa-unlock-alt', title: 'unlock-alt'},
                        { class: 'fa fa-upload', title: 'upload'},
                        { class: 'fa fa-user', title: 'user'},
                        { class: 'fa fa-user-plus', title: 'user-plus'},
                        { class: 'fa fa-user-secret', title: 'user-secret'},
                        { class: 'fa fa-user-times', title: 'user-times'},
                        { class: 'fa fa-users', title: 'users'},
                        { class: 'fa fa-video-camera', title: 'video-camera'},
                        { class: 'fa fa-volume-down', title: 'volume-down'},
                        { class: 'fa fa-volume-off', title: 'volume-off'},
                        { class: 'fa fa-volume-up', title: 'volume-up'},
                        { class: 'fa fa-wheelchair', title: 'wheelchair'},
                        { class: 'fa fa-wifi', title: 'wifi'},
                        { class: 'fa fa-wrench', title: 'wrench'}

                    ],
                    More = [
                        { class: 'fa fa-hand-lizard-o', title: 'hand-lizard-o'},
                        { class: 'fa fa-hand-o-down', title: 'hand-o-down'},
                        { class: 'fa fa-hand-o-left', title: 'hand-o-left'},
                        { class: 'fa fa-hand-o-right', title: 'hand-o-right'},
                        { class: 'fa fa-hand-o-up', title: 'hand-o-up'},
                        { class: 'fa fa-hand-paper-o', title: 'hand-paper-o'},
                        { class: 'fa fa-hand-peace-o', title: 'hand-peace-o'},
                        { class: 'fa fa-hand-pointer-o', title: 'hand-pointer-o'},
                        { class: 'fa fa-hand-rock-o', title: 'hand-rock-o'},
                        { class: 'fa fa-hand-scissors-o', title: 'hand-scissors-o'},
                        { class: 'fa fa-hand-spock-o', title: 'hand-spock-o'},
                        { class: 'fa fa-thumbs-down', title: 'thumbs-down'},
                        { class: 'fa fa-thumbs-o-down', title: 'thumbs-o-down'},
                        { class: 'fa fa-thumbs-o-up', title: 'thumbs-o-up'},
                        { class: 'fa fa-thumbs-up', title: 'thumbs-up'},

                        { class: 'fa fa-ambulance', title: 'ambulance'},
                        { class: 'fa fa-bicycle', title: 'bicycle'},
                        { class: 'fa fa-bus', title: 'bus'},
                        { class: 'fa fa-car', title: 'car'},
                        { class: 'fa fa-fighter-jet', title: 'fighter-jet'},
                        { class: 'fa fa-motorcycle', title: 'motorcycle'},
                        { class: 'fa fa-plane', title: 'plane'},
                        { class: 'fa fa-rocket', title: 'rocket'},
                        { class: 'fa fa-ship', title: 'ship'},
                        { class: 'fa fa-space-shuttle', title: 'space-shuttle'},
                        { class: 'fa fa-subway', title: 'subway'},
                        { class: 'fa fa-taxi', title: 'taxi'},
                        { class: 'fa fa-train', title: 'train'},
                        { class: 'fa fa-truck', title: 'truck'},
                        { class: 'fa fa-wheelchair', title: 'wheelchair'},

                        { class: 'fa fa-genderless', title: 'genderless'},
                        { class: 'fa fa-mars', title: 'mars'},
                        { class: 'fa fa-mars-double', title: 'mars-double'},
                        { class: 'fa fa-mars-stroke', title: 'mars-stroke'},
                        { class: 'fa fa-mars-stroke-h', title: 'mars-stroke-h'},
                        { class: 'fa fa-mars-stroke-v', title: 'mars-stroke-v'},
                        { class: 'fa fa-mercury', title: 'mercury'},
                        { class: 'fa fa-neuter', title: 'neuter'},
                        { class: 'fa fa-transgender', title: 'transgender'},
                        { class: 'fa fa-transgender-alt', title: 'transgender-alt'},
                        { class: 'fa fa-venus', title: 'venus'},
                        { class: 'fa fa-venus-double', title: 'venus-double'},
                        { class: 'fa fa-venus-mars', title: 'venus-mars'},

                        { class: 'fa fa-file', title: 'file'},
                        { class: 'fa fa-file-archive-o', title: 'file-archive-o'},
                        { class: 'fa fa-file-audio-o', title: 'file-audio-o'},
                        { class: 'fa fa-file-code-o', title: 'file-code-o'},
                        { class: 'fa fa-file-excel-o', title: 'file-excel-o'},
                        { class: 'fa fa-file-image-o', title: 'file-image-o'},
                        { class: 'fa fa-file-o', title: 'file-o'},
                        { class: 'fa fa-file-pdf-o', title: 'file-pdf-o'},
                        { class: 'fa fa-file-powerpoint-o', title: 'file-powerpoint-o'},
                        { class: 'fa fa-file-text', title: 'file-text'},
                        { class: 'fa fa-file-text-o', title: 'file-text-o'},
                        { class: 'fa fa-file-video-o', title: 'file-video-o'},
                        { class: 'fa fa-file-word-o', title: 'file-word-o'},

                        { class: 'fa fa-circle-o-notch', title: 'circle-o-notch'},
                        { class: 'fa fa-cog', title: 'cog'},
                        { class: 'fa fa-refresh', title: 'refresh'},
                        { class: 'fa fa-spinner', title: 'spinner'},

                        { class: 'fa fa-check-square', title: 'check-square'},
                        { class: 'fa fa-check-square-o', title: 'check-square-o'},
                        { class: 'fa fa-circle', title: 'circle'},
                        { class: 'fa fa-circle-o', title: 'circle-o'},
                        { class: 'fa fa-dot-circle-o', title: 'dot-circle-o'},
                        { class: 'fa fa-minus-square', title: 'minus-square'},
                        { class: 'fa fa-minus-square-o', title: 'minus-square-o'},
                        { class: 'fa fa-plus-square', title: 'plus-square'},
                        { class: 'fa fa-plus-square-o', title: 'plus-square-o'},
                        { class: 'fa fa-square', title: 'square'},
                        { class: 'fa fa-square-o', title: 'square-o'},

                        { class: 'fa fa-cc-amex', title: 'cc-amex'},
                        { class: 'fa fa-cc-diners-club', title: 'cc-diners-club'},
                        { class: 'fa fa-cc-discover', title: 'cc-discover'},
                        { class: 'fa fa-cc-jcb', title: 'cc-jcb'},
                        { class: 'fa fa-cc-mastercard', title: 'cc-mastercard'},
                        { class: 'fa fa-cc-paypal', title: 'cc-paypal'},
                        { class: 'fa fa-cc-stripe', title: 'cc-stripe'},
                        { class: 'fa fa-cc-visa', title: 'cc-visa'},
                        { class: 'fa fa-credit-card', title: 'credit-card'},
                        { class: 'fa fa-google-wallet', title: 'google-wallet'},
                        { class: 'fa fa-paypal', title: 'paypal'},

                        { class: 'fa fa-area-chart', title: 'area-chart'},
                        { class: 'fa fa-bar-chart', title: 'bar-chart'},
                        { class: 'fa fa-line-chart', title: 'line-chart'},
                        { class: 'fa fa-pie-chart', title: 'pie-chart'},

                        { class: 'fa fa-btc', title: 'btc'},
                        { class: 'fa fa-eur', title: 'eur'},
                        { class: 'fa fa-gbp', title: 'gbp'},
                        { class: 'fa fa-gg', title: 'gg'},
                        { class: 'fa fa-gg-circle', title: 'gg-circle'},
                        { class: 'fa fa-ils', title: 'ils'},
                        { class: 'fa fa-inr', title: 'inr'},
                        { class: 'fa fa-jpy', title: 'jpy'},
                        { class: 'fa fa-krw', title: 'krw'},
                        { class: 'fa fa-money', title: 'money'},
                        { class: 'fa fa-rub', title: 'rub'},
                        { class: 'fa fa-try', title: 'try'},
                        { class: 'fa fa-usd', title: 'usd'},

                        { class: 'fa fa-arrows-alt', title: 'arrows-alt'},
                        { class: 'fa fa-backward', title: 'backward'},
                        { class: 'fa fa-compress', title: 'compress'},
                        { class: 'fa fa-eject', title: 'eject'},
                        { class: 'fa fa-expand', title: 'expand'},
                        { class: 'fa fa-fast-backward', title: 'fast-backward'},
                        { class: 'fa fa-fast-forward', title: 'fast-forward'},
                        { class: 'fa fa-forward', title: 'forward'},
                        { class: 'fa fa-pause', title: 'pause'},
                        { class: 'fa fa-play', title: 'play'},
                        { class: 'fa fa-play-circle', title: 'play-circle'},
                        { class: 'fa fa-play-circle-o', title: 'play-circle-o'},
                        { class: 'fa fa-random', title: 'random'},
                        { class: 'fa fa-step-backward', title: 'step-backward'},
                        { class: 'fa fa-step-forward', title: 'step-forward'},
                        { class: 'fa fa-stop', title: 'stop'},
                        { class: 'fa fa-youtube-play', title: 'youtube-play'},

                        { class: 'fa fa-ambulance', title: 'ambulance'},
                        { class: 'fa fa-h-square', title: 'h-square'},
                        { class: 'fa fa-heart', title: 'heart'},
                        { class: 'fa fa-heart-o', title: 'heart-o'},
                        { class: 'fa fa-heartbeat', title: 'heartbeat'},
                        { class: 'fa fa-hospital-o', title: 'hospital-o'},
                        { class: 'fa fa-medkit', title: 'medkit'},
                        { class: 'fa fa-plus-square', title: 'plus-square'},
                        { class: 'fa fa-stethoscope', title: 'stethoscope'},
                        { class: 'fa fa-user-md', title: 'user-md'},
                        { class: 'fa fa-wheelchair', title: 'wheelchair'}

                    ],
                    TextEditor = [
                        { class: 'fa fa-align-center', title: 'align-center'},
                        { class: 'fa fa-align-justify', title: 'align-justify'},
                        { class: 'fa fa-align-left', title: 'align-left'},
                        { class: 'fa fa-align-right', title: 'align-right'},
                        { class: 'fa fa-bold', title: 'bold'},
                        { class: 'fa fa-chain-broken', title: 'chain-broken'},
                        { class: 'fa fa-clipboard', title: 'clipboard'},
                        { class: 'fa fa-columns', title: 'columns'},
                        { class: 'fa fa-eraser', title: 'eraser'},
                        { class: 'fa fa-file', title: 'file'},
                        { class: 'fa fa-file-o', title: 'file-o'},
                        { class: 'fa fa-file-text', title: 'file-text'},
                        { class: 'fa fa-file-text-o', title: 'file-text-o'},
                        { class: 'fa fa-files-o', title: 'files-o'},
                        { class: 'fa fa-floppy-o', title: 'floppy-o'},
                        { class: 'fa fa-font', title: 'font'},
                        { class: 'fa fa-header', title: 'header'},
                        { class: 'fa fa-indent', title: 'indent'},
                        { class: 'fa fa-italic', title: 'italic'},
                        { class: 'fa fa-link', title: 'link'},
                        { class: 'fa fa-list', title: 'list'},
                        { class: 'fa fa-list-alt', title: 'list-alt'},
                        { class: 'fa fa-list-ol', title: 'list-ol'},
                        { class: 'fa fa-list-ul', title: 'list-ul'},
                        { class: 'fa fa-outdent', title: 'outdent'},
                        { class: 'fa fa-paperclip', title: 'paperclip'},
                        { class: 'fa fa-paragraph', title: 'paragraph'},
                        { class: 'fa fa-repeat', title: 'repeat'},
                        { class: 'fa fa-scissors', title: 'scissors'},
                        { class: 'fa fa-strikethrough', title: 'strikethrough'},
                        { class: 'fa fa-subscript', title: 'subscript'},
                        { class: 'fa fa-superscript', title: 'superscript'},
                        { class: 'fa fa-table', title: 'table'},
                        { class: 'fa fa-text-height', title: 'text-height'},
                        { class: 'fa fa-text-width', title: 'text-width'},
                        { class: 'fa fa-th', title: 'th'},
                        { class: 'fa fa-th-large', title: 'th-large'},
                        { class: 'fa fa-th-list', title: 'th-list'},
                        { class: 'fa fa-underline', title: 'underline'},
                        { class: 'fa fa-undo', title: 'undo'}

                    ],
                    Directional = [
                        { class: 'fa fa-angle-double-down', title: 'angle-double-down'},
                        { class: 'fa fa-angle-double-left', title: 'angle-double-left'},
                        { class: 'fa fa-angle-double-right', title: 'angle-double-right'},
                        { class: 'fa fa-angle-double-up', title: 'angle-double-up'},
                        { class: 'fa fa-angle-down', title: 'angle-down'},
                        { class: 'fa fa-angle-left', title: 'angle-left'},
                        { class: 'fa fa-angle-right', title: 'angle-right'},
                        { class: 'fa fa-angle-up', title: 'angle-up'},
                        { class: 'fa fa-arrow-circle-down', title: 'arrow-circle-down'},
                        { class: 'fa fa-arrow-circle-left', title: 'arrow-circle-left'},
                        { class: 'fa fa-arrow-circle-o-down', title: 'arrow-circle-o-down'},
                        { class: 'fa fa-arrow-circle-o-left', title: 'arrow-circle-o-left'},
                        { class: 'fa fa-arrow-circle-o-right', title: 'arrow-circle-o-right'},
                        { class: 'fa fa-arrow-circle-o-up', title: 'arrow-circle-o-up'},
                        { class: 'fa fa-arrow-circle-right', title: 'arrow-circle-right'},
                        { class: 'fa fa-arrow-circle-up', title: 'arrow-circle-up'},
                        { class: 'fa fa-arrow-down', title: 'arrow-down'},
                        { class: 'fa fa-arrow-left', title: 'arrow-left'},
                        { class: 'fa fa-arrow-right', title: 'arrow-right'},
                        { class: 'fa fa-arrow-up', title: 'arrow-up'},
                        { class: 'fa fa-arrows', title: 'arrows'},
                        { class: 'fa fa-arrows-alt', title: 'arrows-alt'},
                        { class: 'fa fa-arrows-h', title: 'arrows-h'},
                        { class: 'fa fa-arrows-v', title: 'arrows-v'},
                        { class: 'fa fa-caret-down', title: 'caret-down'},
                        { class: 'fa fa-caret-left', title: 'caret-left'},
                        { class: 'fa fa-caret-right', title: 'caret-right'},
                        { class: 'fa fa-caret-square-o-down', title: 'caret-square-o-down'},
                        { class: 'fa fa-caret-square-o-left', title: 'caret-square-o-left'},
                        { class: 'fa fa-caret-square-o-right', title: 'caret-square-o-right'},
                        { class: 'fa fa-caret-square-o-up', title: 'caret-square-o-up'},
                        { class: 'fa fa-caret-up', title: 'caret-up'},
                        { class: 'fa fa-chevron-circle-down', title: 'chevron-circle-down'},
                        { class: 'fa fa-chevron-circle-left', title: 'chevron-circle-left'},
                        { class: 'fa fa-chevron-circle-right', title: 'chevron-circle-right'},
                        { class: 'fa fa-chevron-circle-up', title: 'chevron-circle-up'},
                        { class: 'fa fa-chevron-down', title: 'chevron-down'},
                        { class: 'fa fa-chevron-left', title: 'chevron-left'},
                        { class: 'fa fa-chevron-right', title: 'chevron-right'},
                        { class: 'fa fa-chevron-up', title: 'chevron-up'},
                        { class: 'fa fa-exchange', title: 'exchange'},
                        { class: 'fa fa-hand-o-down', title: 'hand-o-down'},
                        { class: 'fa fa-hand-o-left', title: 'hand-o-left'},
                        { class: 'fa fa-hand-o-right', title: 'hand-o-right'},
                        { class: 'fa fa-hand-o-up', title: 'hand-o-up'},
                        { class: 'fa fa-long-arrow-down', title: 'long-arrow-down'},
                        { class: 'fa fa-long-arrow-left', title: 'long-arrow-left'},
                        { class: 'fa fa-long-arrow-right', title: 'long-arrow-right'},
                        { class: 'fa fa-long-arrow-up', title: 'long-arrow-up'}

                    ],
                    Brand = [
                        { class: 'fa fa-500px', title: '500px'},
                        { class: 'fa fa-adn', title: 'adn'},
                        { class: 'fa fa-amazon', title: 'amazon'},
                        { class: 'fa fa-android', title: 'android'},
                        { class: 'fa fa-angellist', title: 'angellist'},
                        { class: 'fa fa-apple', title: 'apple'},
                        { class: 'fa fa-behance', title: 'behance'},
                        { class: 'fa fa-behance-square', title: 'behance-square'},
                        { class: 'fa fa-bitbucket', title: 'bitbucket'},
                        { class: 'fa fa-bitbucket-square', title: 'bitbucket-square'},
                        { class: 'fa fa-black-tie', title: 'black-tie'},
                        { class: 'fa fa-btc', title: 'btc'},
                        { class: 'fa fa-buysellads', title: 'buysellads'},
                        { class: 'fa fa-cc-amex', title: 'cc-amex'},
                        { class: 'fa fa-cc-diners-club', title: 'cc-diners-club'},
                        { class: 'fa fa-cc-discover', title: 'cc-discover'},
                        { class: 'fa fa-cc-jcb', title: 'cc-jcb'},
                        { class: 'fa fa-cc-mastercard', title: 'cc-mastercard'},
                        { class: 'fa fa-cc-paypal', title: 'cc-paypal'},
                        { class: 'fa fa-cc-stripe', title: 'cc-stripe'},
                        { class: 'fa fa-cc-visa', title: 'cc-visa'},
                        { class: 'fa fa-chrome', title: 'chrome'},
                        { class: 'fa fa-codepen', title: 'codepen'},
                        { class: 'fa fa-connectdevelop', title: 'connectdevelop'},
                        { class: 'fa fa-contao', title: 'contao'},
                        { class: 'fa fa-css3', title: 'css3'},
                        { class: 'fa fa-dashcube', title: 'dashcube'},
                        { class: 'fa fa-delicious', title: 'delicious'},
                        { class: 'fa fa-deviantart', title: 'deviantart'},
                        { class: 'fa fa-digg', title: 'digg'},
                        { class: 'fa fa-dribbble', title: 'dribbble'},
                        { class: 'fa fa-dropbox', title: 'dropbox'},
                        { class: 'fa fa-drupal', title: 'drupal'},
                        { class: 'fa fa-empire', title: 'empire'},
                        { class: 'fa fa-expeditedssl', title: 'expeditedssl'},
                        { class: 'fa fa-facebook', title: 'facebook'},
                        { class: 'fa fa-facebook-official', title: 'facebook-official'},
                        { class: 'fa fa-facebook-square', title: 'facebook-square'},
                        { class: 'fa fa-firefox', title: 'firefox'},
                        { class: 'fa fa-flickr', title: 'flickr'},
                        { class: 'fa fa-fonticons', title: 'fonticons'},
                        { class: 'fa fa-forumbee', title: 'forumbee'},
                        { class: 'fa fa-foursquare', title: 'foursquare'},
                        { class: 'fa fa-get-pocket', title: 'get-pocket'},
                        { class: 'fa fa-gg', title: 'gg'},
                        { class: 'fa fa-gg-circle', title: 'gg-circle'},
                        { class: 'fa fa-git', title: 'git'},
                        { class: 'fa fa-git-square', title: 'git-square'},
                        { class: 'fa fa-github', title: 'github'},
                        { class: 'fa fa-github-alt', title: 'github-alt'},
                        { class: 'fa fa-github-square', title: 'github-square'},
                        { class: 'fa fa-google', title: 'google'},
                        { class: 'fa fa-google-plus', title: 'google-plus'},
                        { class: 'fa fa-google-plus-square', title: 'google-plus-square'},
                        { class: 'fa fa-google-wallet', title: 'google-wallet'},
                        { class: 'fa fa-gratipay', title: 'gratipay'},
                        { class: 'fa fa-hacker-news', title: 'hacker-news'},
                        { class: 'fa fa-houzz', title: 'houzz'},
                        { class: 'fa fa-html5', title: 'html5'},
                        { class: 'fa fa-instagram', title: 'instagram'},
                        { class: 'fa fa-internet-explorer', title: 'internet-explorer'},
                        { class: 'fa fa-ioxhost', title: 'ioxhost'},
                        { class: 'fa fa-joomla', title: 'joomla'},
                        { class: 'fa fa-jsfiddle', title: 'jsfiddle'},
                        { class: 'fa fa-lastfm', title: 'lastfm'},
                        { class: 'fa fa-lastfm-square', title: 'lastfm-square'},
                        { class: 'fa fa-leanpub', title: 'leanpub'},
                        { class: 'fa fa-linkedin', title: 'linkedin'},
                        { class: 'fa fa-linkedin-square', title: 'linkedin-square'},
                        { class: 'fa fa-linux', title: 'linux'},
                        { class: 'fa fa-maxcdn', title: 'maxcdn'},
                        { class: 'fa fa-meanpath', title: 'meanpath'},
                        { class: 'fa fa-medium', title: 'medium'},
                        { class: 'fa fa-odnoklassniki', title: 'odnoklassniki'},
                        { class: 'fa fa-odnoklassniki-square', title: 'odnoklassniki-square'},
                        { class: 'fa fa-opencart', title: 'opencart'},
                        { class: 'fa fa-openid', title: 'openid'},
                        { class: 'fa fa-opera', title: 'opera'},
                        { class: 'fa fa-optin-monster', title: 'optin-monster'},
                        { class: 'fa fa-pagelines', title: 'pagelines'},
                        { class: 'fa fa-paypal', title: 'paypal'},
                        { class: 'fa fa-pied-piper', title: 'pied-piper'},
                        { class: 'fa fa-pied-piper-alt', title: 'pied-piper-alt'},
                        { class: 'fa fa-pinterest', title: 'pinterest'},
                        { class: 'fa fa-pinterest-p', title: 'pinterest-p'},
                        { class: 'fa fa-pinterest-square', title: 'pinterest-square'},
                        { class: 'fa fa-qq', title: 'qq'},
                        { class: 'fa fa-rebel', title: 'rebel'},
                        { class: 'fa fa-reddit', title: 'reddit'},
                        { class: 'fa fa-reddit-square', title: 'reddit-square'},
                        { class: 'fa fa-renren', title: 'renren'},
                        { class: 'fa fa-safari', title: 'safari'},
                        { class: 'fa fa-sellsy', title: 'sellsy'},
                        { class: 'fa fa-share-alt', title: 'share-alt'},
                        { class: 'fa fa-share-alt-square', title: 'share-alt-square'},
                        { class: 'fa fa-shirtsinbulk', title: 'shirtsinbulk'},
                        { class: 'fa fa-simplybuilt', title: 'simplybuilt'},
                        { class: 'fa fa-skyatlas', title: 'skyatlas'},
                        { class: 'fa fa-skype', title: 'skype'},
                        { class: 'fa fa-slack', title: 'slack'},
                        { class: 'fa fa-slideshare', title: 'slideshare'},
                        { class: 'fa fa-soundcloud', title: 'soundcloud'},
                        { class: 'fa fa-spotify', title: 'spotify'},
                        { class: 'fa fa-stack-exchange', title: 'stack-exchange'},
                        { class: 'fa fa-stack-overflow', title: 'stack-overflow'},
                        { class: 'fa fa-steam', title: 'steam'},
                        { class: 'fa fa-steam-square', title: 'steam-square'},
                        { class: 'fa fa-stumbleupon', title: 'stumbleupon'},
                        { class: 'fa fa-stumbleupon-circle', title: 'stumbleupon-circle'},
                        { class: 'fa fa-tencent-weibo', title: 'tencent-weibo'},
                        { class: 'fa fa-trello', title: 'trello'},
                        { class: 'fa fa-tripadvisor', title: 'tripadvisor'},
                        { class: 'fa fa-tumblr', title: 'tumblr'},
                        { class: 'fa fa-tumblr-square', title: 'tumblr-square'},
                        { class: 'fa fa-twitch', title: 'twitch'},
                        { class: 'fa fa-twitter', title: 'twitter'},
                        { class: 'fa fa-twitter-square', title: 'twitter-square'},
                        { class: 'fa fa-viacoin', title: 'viacoin'},
                        { class: 'fa fa-vimeo', title: 'vimeo'},
                        { class: 'fa fa-vimeo-square', title: 'vimeo-square'},
                        { class: 'fa fa-vine', title: 'vine'},
                        { class: 'fa fa-vk', title: 'vk'},
                        { class: 'fa fa-weibo', title: 'weibo'},
                        { class: 'fa fa-weixin', title: 'weixin'},
                        { class: 'fa fa-whatsapp', title: 'whatsapp'},
                        { class: 'fa fa-wikipedia-w', title: 'wikipedia-w'},
                        { class: 'fa fa-windows', title: 'windows'},
                        { class: 'fa fa-wordpress', title: 'wordpress'},
                        { class: 'fa fa-xing', title: 'xing'},
                        { class: 'fa fa-xing-square', title: 'xing-square'},
                        { class: 'fa fa-y-combinator', title: 'y-combinator'},
                        { class: 'fa fa-yahoo', title: 'yahoo'},
                        { class: 'fa fa-yelp', title: 'yelp'},
                        { class: 'fa fa-youtube', title: 'youtube'},
                        { class: 'fa fa-youtube-play', title: 'youtube-play'},
                        { class: 'fa fa-youtube-square', title: 'youtube-square'},

                    ],
                    New = [
                        { class: 'fa fa-500px', title: '500px'},
                        { class: 'fa fa-amazon', title: 'amazon'},
                        { class: 'fa fa-balance-scale', title: 'balance-scale'},
                        { class: 'fa fa-battery-empty', title: 'battery-empty'},
                        { class: 'fa fa-battery-full', title: 'battery-full'},
                        { class: 'fa fa-battery-half', title: 'battery-half'},
                        { class: 'fa fa-battery-quarter', title: 'battery-quarter'},
                        { class: 'fa fa-battery-three-quarters', title: 'battery-three-quarters'},
                        { class: 'fa fa-black-tie', title: 'black-tie'},
                        { class: 'fa fa-calendar-check-o', title: 'calendar-check-o'},
                        { class: 'fa fa-calendar-minus-o', title: 'calendar-minus-o'},
                        { class: 'fa fa-calendar-plus-o', title: 'calendar-plus-o'},
                        { class: 'fa fa-calendar-times-o', title: 'calendar-times-o'},
                        { class: 'fa fa-cc-diners-club', title: 'cc-diners-club'},
                        { class: 'fa fa-cc-jcb', title: 'cc-jcb'},
                        { class: 'fa fa-chrome', title: 'chrome'},
                        { class: 'fa fa-clone', title: 'clone'},
                        { class: 'fa fa-commenting', title: 'commenting'},
                        { class: 'fa fa-commenting-o', title: 'commenting-o'},
                        { class: 'fa fa-contao', title: 'contao'},
                        { class: 'fa fa-creative-commons', title: 'creative-commons'},
                        { class: 'fa fa-expeditedssl', title: 'expeditedssl'},
                        { class: 'fa fa-firefox', title: 'firefox'},
                        { class: 'fa fa-fonticons', title: 'fonticons'},
                        { class: 'fa fa-genderless', title: 'genderless'},
                        { class: 'fa fa-get-pocket', title: 'get-pocket'},
                        { class: 'fa fa-gg', title: 'gg'},
                        { class: 'fa fa-gg-circle', title: 'gg-circle'},
                        { class: 'fa fa-hand-lizard-o', title: 'hand-lizard-o'},
                        { class: 'fa fa-hand-paper-o', title: 'hand-paper-o'},
                        { class: 'fa fa-hand-peace-o', title: 'hand-peace-o'},
                        { class: 'fa fa-hand-pointer-o', title: 'hand-pointer-o'},
                        { class: 'fa fa-hand-rock-o', title: 'hand-rock-o'},
                        { class: 'fa fa-hand-scissors-o', title: 'hand-scissors-o'},
                        { class: 'fa fa-hand-spock-o', title: 'hand-spock-o'},
                        { class: 'fa fa-hourglass', title: 'hourglass'},
                        { class: 'fa fa-hourglass-end', title: 'hourglass-end'},
                        { class: 'fa fa-hourglass-half', title: 'hourglass-half'},
                        { class: 'fa fa-hourglass-o', title: 'hourglass-o'},
                        { class: 'fa fa-hourglass-start', title: 'hourglass-start'},
                        { class: 'fa fa-houzz', title: 'houzz'},
                        { class: 'fa fa-i-cursor', title: 'i-cursor'},
                        { class: 'fa fa-industry', title: 'industry'},
                        { class: 'fa fa-internet-explorer', title: 'internet-explorer'},
                        { class: 'fa fa-map', title: 'map'},
                        { class: 'fa fa-map-o', title: 'map-o'},
                        { class: 'fa fa-map-pin', title: 'map-pin'},
                        { class: 'fa fa-map-signs', title: 'map-signs'},
                        { class: 'fa fa-mouse-pointer', title: 'mouse-pointer'},
                        { class: 'fa fa-object-group', title: 'object-group'},
                        { class: 'fa fa-object-ungroup', title: 'object-ungroup'},
                        { class: 'fa fa-odnoklassniki', title: 'odnoklassniki'},
                        { class: 'fa fa-odnoklassniki-square', title: 'odnoklassniki-square'},
                        { class: 'fa fa-opencart', title: 'opencart'},
                        { class: 'fa fa-opera', title: 'opera'},
                        { class: 'fa fa-optin-monster', title: 'optin-monster'},
                        { class: 'fa fa-registered', title: 'registered'},
                        { class: 'fa fa-safari', title: 'safari'},
                        { class: 'fa fa-sticky-note', title: 'sticky-note'},
                        { class: 'fa fa-sticky-note-o', title: 'sticky-note-o'},
                        { class: 'fa fa-television', title: 'television'},
                        { class: 'fa fa-trademark', title: 'trademark'},
                        { class: 'fa fa-tripadvisor', title: 'tripadvisor'},
                        { class: 'fa fa-vimeo', title: 'vimeo'},
                        { class: 'fa fa-wikipedia-w', title: 'wikipedia-w'},
                        { class: 'fa fa-y-combinator', title: 'y-combinator'}
                    ]
                ];

                /**
                 * Registering plugin "About" information
                 */
                var pluginInformation = {
                    version: '2.0',
                    developer: 'Pascal Mayer',
                    developerUrl: '',
                    copyrightOwner: '',
                    sponsor: '',
                    sponsorUrl: '',
                    license: 'GPL'
                };
                this.registerPluginInformation(pluginInformation);

                /**
                 * Registering the button
                 */
                var buttonId = 'InsertIcon';
                var buttonConfiguration = {
                    id: buttonId,
                    tooltip: this.localize('fontawesome'),
                    action: 'onButtonPress',
                    dialog: true,
                    iconCls: 'htmlarea-action-iconfont-icon-insert',
                    hotKey: (this.pageTSConfiguration ? this.pageTSConfiguration.hotKey : null)
                };
                this.registerButton(buttonConfiguration);
                return true;
            },

            /**
             * This function gets called when the button was pressed
             *
             * @param editor
             * @param id
             * @return boolean false if action is completed
             */
            onButtonPress: function (editor, id) {
                var buttonId = this.translateHotKey(id);
                buttonId = buttonId ? buttonId : id;
                this.openDialogue(
                    'fontawesome',
                    buttonId,
                    this.getWindowDimensions({width: 750, height: 560}, buttonId),
                    this.buildTabs()
                );
                return false;
            },

            /**
             * Open the dialogue window
             *
             * @param title the window title
             * @param buttonId the itemId of the button that was pressed
             * @param dimensions the opening width of the window
             * @param tabItems the configuration of the tabbed panel
             * @return void
             */
            openDialogue: function (title, buttonId, dimensions, tabItems) {
                this.dialog = new Ext.Window({
                    title: this.localize(title),
                    cls: 'htmlarea-window',
                    border: false,
                    width: dimensions.width,
                    height: dimensions.height,
                    iconCls: this.getButton(buttonId).iconCls,
                    listeners: {
                        close: {
                            fn: this.onClose,
                            scope: this
                        }
                    },
                    items: {
                        xtype: 'tabpanel',
                        activeTab: 0,
                        autoScroll: true,
                        listeners: {
                            tabchange: {
                                fn: this.syncHeight,
                                scope: this
                            }
                        },
                        items: tabItems
                    },

                    buttons: [
                        this.buildButtonConfig('Cancel', this.onCancel)
                    ]
                });
                this.show();
            },

            /**
             * Build the dialogue tab items config
             *
             * @return object the tab items configuration
             */
            buildTabs: function () {
                var tabItems = [];
                Ext.iterate(this.icons, function (id, map) {
                    tabItems.push({
                        xtype: 'box',
                        cls: 'fontawesome-array',
                        title: this.localize('fontawesome.group.' + map),
                        itemId: map,
                        tpl: new Ext.XTemplate(
                            '<link rel="stylesheet" type="text/css" href="../typo3conf/ext/iconfont/Resources/Public/Lib/font-awesome/css/font-awesome.min.css" media="all"> ' +
                            '<div>' +
                            '   <tpl for=".">' +
                            '       <a href="#" class="icon" hidefocus="on" ext:class="{class}"  ext:qtip="{title}" title="{title}">' +
                            '           <i class="{class}" style="background: #FFF; line-height: 22px; font-size: 20px; border: 1px solid #CCC; margin: 2px; display: inline-block; width: 22px; height: 22px; text-align: center; vertical-align: middle;" /></i>' +
                            '       </a>' +
                            '   </tpl>' +
                            '</div>'
                        ),
                        listeners: {
                            render: {
                                fn: this.render,
                                scope: this
                            }
                        }
                    });
                }, this);
                return tabItems;
            },

            render: function (component) {
                component.tpl.overwrite(component.el, this.icons[component.itemId]);
                component.mon(component.el, 'click', this.insertITag, this, {delegate: 'a'});
            },

            insertITag: function (event, target) {
                event.stopEvent();
                this.restoreSelection();
                var iTag = this.editor.document.createElement('i');
                iTag.setAttribute('class', target.getAttribute('ext:class'));
                this.editor.getSelection().insertNode(iTag);
                if (!Ext.isIE) {
                    this.editor.getSelection().selectNode(iTag, false);
                }
                this.close();
                return false;
            },

            resetFocus: function () {
                this.restoreSelection();
            }
        });

        return InsertIcon;

    });